PianoPlayer Web API

GitHub Repository PyPI Package

✦ Upload a score and download the annotated MusicXML output ✦

Input Score
Choose file .xml, .mxl, .mid, .midi, .mscz, .mscx, .txt
Hand Size
Annotate
Start at Measure
Stop at Measure

Solver

Depth of search (0=auto)
Chord Stagger (seconds)

Output

Show annotations below beam

Routing

Routing Mode
Right Part number
Left Part number
Right Staff number (0=auto)
Left Staff number (0=auto)
Ready
Output: the download is a MusicXML file with fingering annotations added to your score.
Existing (pre-fingered) anchors are preserved and shown as circled numbers.
You can open the result with MuseScore or any MusicXML-compatible viewer.